mailr6478 - /1.3/data/__init__.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on June 24, 2008 - 22:48:
Author: bugman
Date: Tue Jun 24 22:48:38 2008
New Revision: 6478

URL: http://svn.gna.org/viewcvs/relax?rev=6478&view=rev
Log:
Added the creation time to the results file.


Modified:
    1.3/data/__init__.py

Modified: 1.3/data/__init__.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/data/__init__.py?rev=6478&r1=6477&r2=6478&view=diff
==============================================================================
--- 1.3/data/__init__.py (original)
+++ 1.3/data/__init__.py Tue Jun 24 22:48:38 2008
@@ -27,6 +27,7 @@
 # Python module imports.
 from re import search
 from string import split
+from time import asctime
 import xml.dom.ext
 import xml.dom.minidom
 
@@ -191,8 +192,9 @@
         # Append the element.
         xmldoc.appendChild(top_element)
 
         # Set the relax version number.
         top_element.setAttribute('version', version)
+        top_element.setAttribute('time', asctime())
 
         # Create the pipe XML element and add it to the top level XML 
@@ -191,8 +192,9 @@
         xmldoc.appendChild(top_element)
 
-        # Set the relax version number.
+        # Set the relax version number, and add a creation time.
         top_element.setAttribute('version', version)
element.
         pipe_element = xmldoc.createElement('pipe')




Related Messages


Powered by MHonArc, Updated Tue Jun 24 23:40:18 2008